@@ -664,7 +664,7 @@ def sayLinux(text, untilDone=True, lipSync=True, hdmiAudio=False, soundDelay=0):
         safetext = re.sub(r'[^ .a-zA-Z0-9?\']+', '', text)
 
         # Create a bash command with the desired text. The command writes two files, a .wav with the speech audio and a .txt file containing the phonemes and the times.
-        bashcommand = "festival -b '(set! mytext (Utterance Text " + '"' + safetext + '"))' + "' '(utt.synth mytext)' '(utt.save.wave mytext " + '"'++")' + "' '(utt.save.segs mytext " + '"phonemes"' + ")'"
+        bashcommand = "festival -b '(set! mytext (Utterance Text " + '"' + safetext + '"))' + "' '(utt.synth mytext)' '(utt.save.wave mytext " + '"'+file+")' + "' '(utt.save.segs mytext " + '"phonemes"' + ")'"
 
         # Execute bash command.
         subprocess.call(bashcommand, shell=True)
